:orphan:

Reference
=========

Detailed information including autogenerated code documentation.

.. toctree::
    :caption: Reference

    reference/old_readme

    reference/contributing
    Releases <https://github.com/gilesknap/mciwb/releases>
    Index <genindex.html#http://>

..
    Index link above is a hack to make genindex.html a relative link
    https://stackoverflow.com/a/31820846
